@@ -40,7 +40,6 @@ typedef struct
 	char tsid[16];
 }	slot_t;
 
-static const char *argv0 = LIBEXEC_PROGRAM;
 static slot_t *slot;
 static int pid = 0;
 static int pri = 1;
@@ -136,32 +135,6 @@ BayonneSysexec::~BayonneSysexec()
 	terminate();
 }
 
-void BayonneSysexec::setEngine(const char *engine)
-{
-	char *n = newString(argv0, strlen(argv0) + 16);
-	char *ep = strrchr(n, '/');
-	if(!ep)
-		return;
-	snprintf(++ep, 16, "%s.bin", engine);
-	argv0 = n;
-}
-
-void BayonneSysexec::setArgv0(const char *cp)
-{
-	char *n = newString(cp);
-	char *ep;
-
-	ep = strstr(n, "/.libs/");
-	if(!ep)
-		ep = strrchr(n, '/');
-	if(ep)
-		++ep;
-	else
-		ep = n;
-	strcpy(ep, "libexec.bin");
-	argv0 = n;
-}
-
 void BayonneSysexec::run(void)
 {
 	BayonneTSession *s;
@@ -453,10 +426,17 @@ void BayonneSysexec::allocate(const char *libexec, size_t bs, int pri, const cha
 	argv[5] = newString(syspath);
 	argv[6] = NULL;
 
-
 	for(int i = 3; i < 100; ++i)
 		::close(i);
-	execv(argv0, argv);
+
+	if(Bayonne::provision_test)
+		snprintf(path, sizeof(path), "%s/server/%s",
+			SOURCE_FILES, provision_libexec);
+	else
+		snprintf(path, sizeof(path), "%s/%s",
+			LIBDIR_FILES, provision_libexec);		
+
+	execv(path, argv);
 	slog.error("libexec failed; exiting...");
 	::exit(-1);
 }
