@@ -199,14 +199,6 @@ Thread(atoi(getLast("priority")), atoi(getLast("stack")) * 1024)
 		AudioCodec::endCodec(codec);
 	}	
 
-#ifdef	HAVE_TESTING
-        if(Bayonne::provision_test)
-        {    
-		server->setValue("sip.conf", SOURCE_FILES "/config/sip.conf");
-		server->setValue("uri.conf", SOURCE_FILES "/config/uri.conf");
-		return;
-	}
-#endif
 	server->setValue("sip.conf", CONFIG_FILES "/sip.conf");
 	server->setValue("uri.conf", CONFIG_FILES "/uri.conf");
 }
