@@ -92,7 +92,12 @@ static Keydata::Define paths[] = {
 #endif
 	{NULL, NULL}};
 
+static Keydata::Define gateway[] = {
+	{"binding", "troll"},
+	{NULL, NULL}};
+
 static Keydata::Define server[] = {
+	{"argv0", "bayonne"},
 	{"user", "bayonne"},
 	{"group", "bayonne"},
 	{"language", "none"},
@@ -122,11 +127,13 @@ Keydata keypaths(paths, "/bayonne/paths");
 Keydata keyserver(server, "/bayonne/server");
 Keydata keyengine(engine, "/bayonne/engine");
 Keydata keyswitch(switchkeys, "/bayonne/switch");
+Keydata keygateway(gateway, "/bayonne/gateway");
 #else
 Keydata keypaths(paths, "/bayonne/server/paths");
 Keydata keyserver(server, "/bayonne/server/server");
 Keydata keyengine(engine, "/bayonne/server/engine");
 Keydata keyswitch(switchkeys, "/bayonne/server/switch");
+Keydata keygateway(gateway, "/bayonne/server/gateway");
 #endif
 Keydata keyoptions;
 
@@ -211,6 +218,7 @@ void liveConfig(void)
 	char *p;
 	const char *cp;
 	unsigned timeslots = atoi(keyswitch.getLast("timeslots"));
+	const char *argv0 = keyserver.getLast("argv0");
 
 #ifdef	WIN32
         char nodename[MAX_COMPUTERNAME_LENGTH + 1];
@@ -275,14 +283,14 @@ void liveConfig(void)
 	if(!userid || !stricmp(userid, "root"))
 		userid="bayonne";	
 
-	snprintf(path, sizeof(path), "/tmp/bayonne-%s", userid);
+	snprintf(path, sizeof(path), "/tmp/%s-%s", argv0, userid);
 	keypaths.setValue("tmp", path);
 	purgedir(path);
 	Dir::create(path);
 
 	if(canModify("/dev/shm"))
 	{
-		snprintf(path, sizeof(path), "/dev/shm/bayonne-%s", userid);
+		snprintf(path, sizeof(path), "/dev/shm/%s-%s", argv0, userid);
 		keypaths.setValue("tmpfs", path);
 		purgedir(path);
 		Dir::create(path);
@@ -510,6 +518,7 @@ void loadConfig(void)
 		keyserver.load("~bayonne/server");
 		keyengine.load("~bayonne/engine");
 		keyswitch.load("~bayonne/switch");
+		keygateway.load("~bayonne/gateway");
 		runtime.loadPrefix("virtual", "~bayonne/virtual");
 	}
 
@@ -519,6 +528,7 @@ void loadConfig(void)
 		keyserver.load("/bayonne/provision/server");
 		keyengine.load("/bayonne/provision/engine");
 		keyswitch.load("/bayonne/provision/switch");
+		keygateway.load("/bayonne/provision/gateway");
 		runtime.loadPrefix("virtual", "/bayonne/provision/virtual");
 	}
 
@@ -603,6 +613,7 @@ retry:
         if(!strnicmp(option, "-bind=", 6))
         {
                 keyserver.setValue("binding", option + 6);    
+		keygateway.setValue("bidning", option + 6);
                 ++argv;
                 goto retry;
         }  
@@ -610,6 +621,7 @@ retry:
         if(!strnicmp(option, "-trunking=", 10))
         {
                 keyswitch.setValue("trunking", option + 10);    
+		keygateway.setValue("trunking", option + 10);
                 ++argv;
                 goto retry;
         }
@@ -732,6 +744,7 @@ retry:
         if(!strnicmp(option, "-timeslots=", 11))
         {
 		keyswitch.setValue("timeslots", option + 11);
+		keygateway.setValue("timeslots", option + 11);
                 ++argv;
                 goto retry;
         }
@@ -831,7 +844,9 @@ retry:
                         cerr << "bayonne: -binding: missing argument" << endl;
                         exit(-1);
                 }
-                keyserver.setValue("binding", *(argv++));
+                keyserver.setValue("binding", *argv);
+		keygateway.setValue("binding", *argv);
+		++argv;
                 goto retry;
         } 
 
@@ -843,7 +858,9 @@ retry:
                         cerr << "bayonne: -trunking: missing argument" << endl;
                         exit(-1);
                 }
-                keyswitch.setValue("trunking", *(argv++));
+                keyswitch.setValue("trunking", *argv);
+		keygateway.setValue("trunking", *argv);
+		++argv;
                 goto retry;
         }  
 
@@ -867,7 +884,9 @@ retry:
 			cerr << "bayonne: -timeslots: missing argument" << endl;
                         exit(-1);
                 }
-		keyswitch.setValue("timeslots", *(argv++));
+		keyswitch.setValue("timeslots", *argv);
+		keygateway.setValue("timeslots", *argv);
+		++argv;
                 goto retry;
 	}
 #endif
