@@ -47,6 +47,10 @@ class ListThread : public ScriptThread, public Dir
 private:
 	const char *prefix, *suffix;
 	Symbol *sym;
+	bool longinfo;
+	char filepath[MAX_PATHNAME];
+	unsigned fplen;
+	AudioFile af;
 
 	void run(void);
 
